<?php $root="../"; ?>
<?php require($root."navigation.php"); ?>

<html>
<head>
  <title>LibMesh Class Documentation</title>
  <?php load_style($root); ?>
</head>

<body>
<?php make_navigation("documentation",$root)?>

<div class="content">
<!-- Generated by Doxygen 1.7.3 -->
  <div id="navrow1" class="tabs">
    <ul class="tablist">
      <li class="current"><a href="index.php"><span>Main&#160;Page</span></a></li>
      <li><a href="namespaces.php"><span>Namespaces</span></a></li>
      <li><a href="annotated.php"><span>Classes</span></a></li>
      <li><a href="files.php"><span>Files</span></a></li>
      <li><a href="dirs.php"><span>Directories</span></a></li>
    </ul>
  </div>
</div>
<div class="header">
  <div class="headertitle">
<h1><a class="el" href="namespacelibMesh.php">libMesh</a> - A C++ Finite Element Library </h1>  </div>
</div>
<div class="contents">
<div class="textblock"><p>The <code><a class="el" href="namespacelibMesh.php">libMesh</a></code> library is a C++ framework for the numerical simulation of partial differential equations on serial and parallel platforms. Development began in March 2002 with the intent of providing a friendly interface to a number of high-quality software packages that are currently available.</p>
<p>A major goal of the library is to provide support for adaptive mesh refinement (AMR) computations in parallel while allowing a research scientist to focus on the physics they are modeling. The library currently offers:</p>
<ul>
<li>Partitioning Algorithms<ul>
<li><a class="el" href="namespaceMetis.php">Metis</a> K-Way weighted graph partitioning</li>
<li><a class="el" href="namespaceParmetis.php">Parmetis</a> parallel graph partitioning</li>
<li>Hilbert and Morton-ordered space filling curves</li>
</ul>
</li>
</ul>
<ul>
<li>Generic 2D Finite Elements<ul>
<li>3 and 6 noded triangles (<code><a class="el" href="classTri3.php">Tri3</a></code>, <code><a class="el" href="classTri6.php">Tri6</a></code>)</li>
<li>4, 8, and 9 noded quadrilaterals (<code><a class="el" href="classQuad4.php">Quad4</a></code>, <code><a class="el" href="classQuad8.php">Quad8</a></code>, <code><a class="el" href="classQuad9.php">Quad9</a></code>)</li>
<li>4 and 6 noded infinite quadrilaterals (<code><a class="el" href="classInfQuad4.php">InfQuad4</a></code>, <code><a class="el" href="classInfQuad6.php">InfQuad6</a></code>)</li>
</ul>
</li>
</ul>
<ul>
<li>Generic 3D Finite Elements<ul>
<li>4 and 10 noded tetrahedrals (<code><a class="el" href="classTet4.php">Tet4</a></code>, <code><a class="el" href="classTet10.php">Tet10</a></code>)</li>
<li>8, 20, and 27 noded hexahedrals (<code><a class="el" href="classHex8.php">Hex8</a></code>, <code><a class="el" href="classHex20.php">Hex20</a></code>, <code><a class="el" href="classHex27.php">Hex27</a></code>)</li>
<li>6, 15, and 18 noded prisms (<code><a class="el" href="classPrism6.php">Prism6</a></code>, <code><a class="el" href="classPrism15.php">Prism15</a></code>, <code><a class="el" href="classPrism18.php">Prism18</a></code>)</li>
<li>5 noded pyramids (<code><a class="el" href="classPyramid5.php">Pyramid5</a></code>)</li>
<li>8, 16, and 18 noded infinite hexahedrals (<code><a class="el" href="classInfHex8.php">InfHex8</a></code>, <code><a class="el" href="classInfHex16.php">InfHex16</a></code>, <code><a class="el" href="classInfHex18.php">InfHex18</a></code>)</li>
<li>6 and 12 noded infinite prisms (<code><a class="el" href="classInfPrism6.php">InfPrism6</a></code>, <code><a class="el" href="classInfPrism12.php">InfPrism12</a></code>)</li>
</ul>
</li>
</ul>
<ul>
<li>Generic Finite Element Families<ul>
<li>Lagrange</li>
<li>Hierarchic</li>
<li>Discontinuous Monomials</li>
</ul>
</li>
</ul>
<ul>
<li>Dimension-independence<ul>
<li>Operators are defined to allow the same code to run unmodified on 2D and 3D applications</li>
<li>The code you debug and verify on small 2D problems can immediately be applied to large, parallel 3D applications</li>
</ul>
</li>
</ul>
<ul>
<li>Sparse <a class="el" href="classLinear.php">Linear</a> Algebra<ul>
<li><code>PETSc</code> provides a suite of iterative solvers and preconditioners for serial and parallel applications</li>
<li>Complex values are supported with <code>PETSc</code> </li>
<li><code>LASPACK</code> provides iterative solvers and preconditioners for serial applications</li>
<li>The <code><a class="el" href="classSparseMatrix.php">SparseMatrix</a></code>, <code><a class="el" href="classNumericVector.php">NumericVector</a></code>, and <code><a class="el" href="classLinearSolver.php">LinearSolver</a></code> allow for transparent switching between solver packages. Adding a new solver interface is as simple as deriving from these classes</li>
</ul>
</li>
</ul>
<ul>
<li><a class="el" href="classMesh.php">Mesh</a> IO &amp; Format Translation Utilities<ul>
<li>Ideas Universal (UNV) format (.unv) with support through <code><a class="el" href="classMeshData.php">MeshData</a></code> for arbitrary float data, like boundary conditions, associated with mesh entities</li>
<li>Sandia National Labs ExodusII format (.exd)</li>
<li>Amtec Engineering's Tecplot binary format (.plt)</li>
<li>Amtec Engineering's Tecplot ascii format (.dat)</li>
<li>Los Alamos National Labs <a class="el" href="namespaceGMV.php">GMV</a> format (.gmv)</li>
<li>AVS Unstructured UCD format (.ucd)</li>
</ul>
</li>
</ul>
<ul>
<li><a class="el" href="classMesh.php">Mesh</a> Creation &amp; Modification Utilities<ul>
<li>refine or coarsen a mesh: prescribed, level-one-compatible, or uniform</li>
<li>build equispaced n-cubes out of <code><a class="el" href="classEdge2.php">Edge2</a></code>, <code><a class="el" href="classTri3.php">Tri3</a></code>, <code><a class="el" href="classTri6.php">Tri6</a></code>, <code><a class="el" href="classQuad4.php">Quad4</a></code>, <code><a class="el" href="classQuad8.php">Quad8</a></code>, <code><a class="el" href="classQuad9.php">Quad9</a></code>, <code><a class="el" href="classHex8.php">Hex8</a></code>, <code><a class="el" href="classHex20.php">Hex20</a></code>, <code><a class="el" href="classHex27.php">Hex27</a></code> </li>
<li>build circles/spheres out of <code><a class="el" href="classTri3.php">Tri3</a></code>, <code><a class="el" href="classTri6.php">Tri6</a></code>, <code><a class="el" href="classQuad4.php">Quad4</a></code>, <code><a class="el" href="classQuad8.php">Quad8</a></code>, <code><a class="el" href="classQuad9.php">Quad9</a></code>, <code><a class="el" href="classHex8.php">Hex8</a></code> </li>
<li>add infinite elements to a volume-based mesh, handle symmetry planes</li>
<li>convert <code><a class="el" href="classQuad4.php">Quad4</a></code>, <code><a class="el" href="classQuad8.php">Quad8</a></code>, <code><a class="el" href="classQuad9.php">Quad9</a></code> to <code><a class="el" href="classTri3.php">Tri3</a></code>, <code><a class="el" href="classTri6.php">Tri6</a></code> </li>
<li>convert a mesh consisting of any of the fore-mentioned n-dimensional linear elements to their second-order counterparts</li>
<li>distort/translate/rotate/scale a mesh</li>
<li>determine bounding boxes/spheres</li>
<li>extract the mesh boundary for boundary condition handling or as a separate mesh </li>
</ul>
</li>
</ul>
</div></div>
</div>


<?php make_footer() ?>

</body>
</html>
 
